==> tujie-xingxue-dacheng-vol1-2022.10.3.0.tar.gz: tujie-xingxue-dacheng-vol1-2022.10.3.0/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

import setuptools
import TujieXingxueDachengVol1
import os
from os import path

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

for subdir, _, _ in os.walk('TujieXingxueDachengVol1'):
    fname = path.join(subdir, '__init__.py')
    open(fname, 'a').close()
    
setuptools.setup(
    name="tujie-xingxue-dacheng-vol1",
    version=TujieXingxueDachengVol1.__version__,
    url="https://github.com/apachecn/tujie-xingxue-dacheng-vol1",
    author=TujieXingxueDachengVol1.__author__,
    author_email=TujieXingxueDachengVol1.__email__,
    classifiers=[
        "Development Status :: 4 - Beta",
        "Environment :: Console",
        "Intended Audience :: Developers",
        "Intended Audience :: End Users/Desktop",
        "License :: Other/Proprietary License",
        "Natural Language :: Chinese (Simplified)",
        "Natural Language :: English",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Topic :: Text Processing :: Markup :: Markdown",
        "Topic :: Text Processing :: Markup :: HTML",
        "Topic :: Internet :: WWW/HTTP",
        "Topic :: Software Development :: Documentation",
        "Topic :: Documentation",
    ],
    description="图解星学大成一",
    long_description=long_description,
    long_description_content_type="text/markdown",
    keywords=[],
    install_requires=[],
    python_requires=">=3.6",
    entry_points={
        'console_scripts': [
            "tujie-xingxue-dacheng-vol1=TujieXingxueDachengVol1.__main__:main",
            "TujieXingxueDachengVol1=TujieXingxueDachengVol1.__main__:main",
        ],
    },
    packages=setuptools.find_packages(),
    package_data={'': ['*']},
)

==> tujie-xingxue-dacheng-vol2-2022.10.3.0.tar.gz: tujie-xingxue-dacheng-vol2-2022.10.3.0/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

import setuptools
import TujieXingxueDachengVol2
import os
from os import path

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

for subdir, _, _ in os.walk('TujieXingxueDachengVol2'):
    fname = path.join(subdir, '__init__.py')
    open(fname, 'a').close()
    
setuptools.setup(
    name="tujie-xingxue-dacheng-vol2",
    version=TujieXingxueDachengVol2.__version__,
    url="https://github.com/apachecn/tujie-xingxue-dacheng-vol2",
    author=TujieXingxueDachengVol2.__author__,
    author_email=TujieXingxueDachengVol2.__email__,
    classifiers=[
        "Development Status :: 4 - Beta",
        "Environment :: Console",
        "Intended Audience :: Developers",
        "Intended Audience :: End Users/Desktop",
        "License :: Other/Proprietary License",
        "Natural Language :: Chinese (Simplified)",
        "Natural Language :: English",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Topic :: Text Processing :: Markup :: Markdown",
        "Topic :: Text Processing :: Markup :: HTML",
        "Topic :: Internet :: WWW/HTTP",
        "Topic :: Software Development :: Documentation",
        "Topic :: Documentation",
    ],
    description="图解星学大成三",
    long_description=long_description,
    long_description_content_type="text/markdown",
    keywords=[],
    install_requires=[],
    python_requires=">=3.6",
    entry_points={
        'console_scripts': [
            "tujie-xingxue-dacheng-vol2=TujieXingxueDachengVol2.__main__:main",
            "TujieXingxueDachengVol2=TujieXingxueDachengVol2.__main__:main",
        ],
    },
    packages=setuptools.find_packages(),
    package_data={'': ['*']},
)
